# README

The Lute Khmer parser.

See [the wiki](https://github.com/LuteOrg/lute-v3/wiki/Developing-language-parser-plugins) for development notes.

See the [Pypi readme](./README_PyPi.md) for extra config notes.
